# !/bin/bash
# Script to generate image-header as splash screen
# from image file (png or jpeg) defined by variable SPLASH_SCREEN

# Check if SPLASH_SCREEN variable is defined
if [ -z ${SPLASH_SCREEN+x} ]; then
    warning "SPLASH_SCREEN variable is not defined, use default background image"
    SPLASH_SCREEN="${srcDir}/background.png"
fi

# Check if splash screen image exists
if [ ! -f "${SPLASH_SCREEN}" ]; then
    fatal 1 "Splash screen file not found, please set the variable SPLASH_SCREEN to image file location"
fi

# Check if splash screen image format is supported
case $(basename $SPLASH_SCREEN) in
    *.png | *.jpeg)
        log "Splash screen file found: $SPLASH_SCREEN"
        ;;
    *)
        fatal 2 "Splash screen format not supported. Supported format: png, jpeg"
        ;;
esac

# Output file name
SPLASH_SCREEN_BASENAME="${SPLASH_SCREEN##*/}"
IMAGEH="${SPLASH_SCREEN_BASENAME%.*}-img.h"
POKY_IMG=psplash-poky-img.h

# Image header must be generated into source directory
cd ${srcDir}

# convert SPLASH_SCREEN into IMAGEH (cf. make-image-header.sh)
filename=$(basename ${SPLASH_SCREEN})
imageh="${filename%.*}"-img.h
name="POKY_IMG"
gdk-pixbuf-csource --macros ${SPLASH_SCREEN} > $imageh.tmp
sed -e "s/MY_PIXBUF/${name}/g" -e "s/guint8/uint8/g" $imageh.tmp > $(sed -e 's/^.*\///' <<< $imageh) && rm $imageh.tmp


# replace poky image header with our new one
log_exec cp ${IMAGEH} ${POKY_IMG}

cd -