#!/bin/bash
#
# Recipe-specific step for task Install:  (make_install.sh)
#

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

function local_do_make_install() {
	do_make DESTDIR="$installDir" sbindir="/sbin" usbindir="$sbindir" install

	# Info dir listing isn't interesting at this point so remove it if it exists.
	if [ -e "$installDir$infodir/dir" ]; then
		rm -f $installDir$infodir/dir
	fi

	# Enable CREATE_HOME by default.
	sed -i 's/#CREATE_HOME/CREATE_HOME/g' $installDir$sysconfdir/login.defs

	# As we are on an embedded system, ensure the users mailbox is in
	# ~/ not $localstatedir/spool/mail by default, as who knows where or how big
	# $localstatedir is. The system MDA will set this later anyway.
	sed -i 's/MAIL_DIR/#MAIL_DIR/g' $installDir$sysconfdir/login.defs
	sed -i 's/#MAIL_FILE/MAIL_FILE/g' $installDir$sysconfdir/login.defs

	# Disable checking emails.
	sed -i 's/MAIL_CHECK_ENAB/#MAIL_CHECK_ENAB/g' $installDir$sysconfdir/login.defs

	# Comment out SU_NAME to work correctly with busybox
	# See Bug#5359 and Bug#7173
	sed -i 's:^SU_NAME:#SU_NAME:g' $installDir$sysconfdir/login.defs

	# Use proper encryption for passwords
	sed -i 's/^#ENCRYPT_METHOD.*$/ENCRYPT_METHOD SHA512/' $installDir$sysconfdir/login.defs

	# Now we don't have a mail system. Disable mail creation for now.
	sed -i 's:/bin/bash:/bin/sh:g' $installDir$sysconfdir/default/useradd
	sed -i '/^CREATE_MAIL_SPOOL/ s:^:#:' $installDir$sysconfdir/default/useradd

	# Use users group by default
	sed -i 's,^GROUP=1000,GROUP=100,g' $installDir$sysconfdir/default/useradd
	# Ensure that the image has as a $localstatedir/spool/mail dir so shadow can
	# put mailboxes there if the user reconfigures shadow to its
	# defaults (see sed below).
	install -m 0775 -d $installDir$localstatedir/spool/mail
	chown root:mail $installDir$localstatedir/spool/mail

	if [ -e $workDir/pam.d ]; then
		install -d $installDir$sysconfdir/pam.d
		install -m 0644 $workDir/pam.d/* $installDir$sysconfdir/pam.d
		# Remove defaults that are not used when supporting PAM.
		sed -i -f $workDir/login_defs_pam.sed $installDir$sysconfdir/login.defs
	fi

	install -d $installDir$sbindir $installDir/sbin $installDir/bin

	# Move binaries to the locations we want
	rm $installDir$sbindir/vigr
	ln -sf vipw.shadow $installDir/sbin/vigr
	if [ "$sbindir" != "/sbin" ]; then
		mv $installDir$sbindir/vipw $installDir/sbin/vipw
	fi
	if [ "$bindir" != "/bin" ]; then
		mv $installDir$bindir/login $installDir/bin/login
		mv $installDir$bindir/su $installDir/bin/su
	fi

	# Handle link properly after rename, otherwise missing files would
	# lead rpm failed dependencies.
	ln -sf newgrp.shadow $installDir$bindir/sg
}

do_buildstep_prepend

local_do_make_install

do_buildstep_append

